@@ -1,11 +1,16 @@
 import copy
 import math
 import time
-from typing import Dict, Iterable, List, Optional, Tuple, Union
+from typing import Any, Dict, Iterable, List, Optional, Tuple, Union
 
 from typing_extensions import TypedDict
 
-from cognite.client.data_classes._base import CogniteResource, CogniteResourceList
+from cognite.client.data_classes._base import (
+    CognitePrimitiveUpdate,
+    CogniteResource,
+    CogniteResourceList,
+    CogniteUpdate,
+)
 from cognite.client.utils._auxiliary import to_camel_case
 from cognite.experimental.exceptions import ModelFailedException
 
@@ -36,7 +41,7 @@ class ContextualizationJob(CogniteResource):
 
     def update_status(self) -> str:
         """Updates the model status and returns it"""
-        data = self._cognite_client.entity_matching._get(f"{self._status_path}{self.job_id}").json()  # any playground
+        data = self._cognite_client.entity_matching._get(f"{self._status_path}{self.job_id}").json()
         self.status = data["status"]
         self.status_timestamp = data.get("statusTimestamp")
         self.start_timestamp = data.get("startTimestamp")
@@ -77,40 +82,48 @@ class ContextualizationJob(CogniteResource):
         return obj
 
 
-class ContextualizationModel(CogniteResource):
-    """Abstract base class for contextualization models"""
-
-    _STATUS_PATH = None
+class EntityMatchingModel(CogniteResource):
+    _RESOURCE_PATH = "/context/entitymatching"
+    _STATUS_PATH = _RESOURCE_PATH + "/"
 
     def __init__(
         self,
-        model_id=None,
+        id=None,
         status=None,
         error_message=None,
         request_timestamp=None,
         start_timestamp=None,
         status_timestamp=None,
         cognite_client=None,
+        classifier=None,
+        feature_type=None,
+        keys_from_to=None,
+        model_type=None,
+        name=None,
+        description=None,
+        external_id=None,
     ):
-        self.model_id = model_id
+        self.id = id
         self.status = status
         self.request_timestamp = request_timestamp
         self.start_timestamp = start_timestamp
         self.status_timestamp = status_timestamp
         self.error_message = error_message
+        self.classifier = classifier
+        self.feature_type = feature_type
+        self.keys_from_to = keys_from_to
+        self.model_type = model_type
+        self.name = name
+        self.description = description
+        self.external_id = external_id
         self._cognite_client = cognite_client
 
     def __str__(self):
-        return "%s(id: %d,status: %s,error: %s)" % (
-            self.__class__.__name__,
-            self.model_id,
-            self.status,
-            self.error_message,
-        )
+        return "%s(id: %d,status: %s,error: %s)" % (self.__class__.__name__, self.id, self.status, self.error_message,)
 
     def update_status(self) -> str:
         """Updates the model status and returns it"""
-        data = self._cognite_client.entity_matching._get(f"{self._STATUS_PATH}{self.model_id}").json()
+        data = self._cognite_client.entity_matching._get(f"{self._STATUS_PATH}{self.id}").json()
         self.status = data["status"]
         self.status_timestamp = data.get("statusTimestamp")
         self.start_timestamp = data.get("startTimestamp")
@@ -126,12 +139,7 @@ class ContextualizationModel(CogniteResource):
                 break
             time.sleep(interval)
         if self.status == "Failed":
-            raise ModelFailedException(self.__class__.__name__, self.model_id, self.error_message)
-
-
-class EntityMatchingModel(ContextualizationModel):
-    _RESOURCE_PATH = "/context/entity_matching"
-    _STATUS_PATH = _RESOURCE_PATH + "/"
+            raise ModelFailedException(self.__class__.__name__, self.id, self.error_message)
 
     def predict(
         self,
@@ -139,9 +147,8 @@ class EntityMatchingModel(ContextualizationModel):
         match_to: Optional[List[Dict]] = None,
         num_matches=1,
         score_threshold=None,
-        complete_missing=False,
     ) -> ContextualizationJob:
-        """Predict entity matching.
+        """Predict entity matching. NB. blocks and waits for the model to be ready if it has been recently created.
 
         Args:
             match_from: entities to match from, does not need an 'id' field. Tolerant to passing more than is needed or used (e.g. json dump of time series list). If omitted, will use data from fit.
@@ -154,44 +161,27 @@ class EntityMatchingModel(ContextualizationModel):
             ContextualizationJob: object which can be used to wait for and retrieve results."""
         self.wait_for_completion()
         return self._cognite_client.entity_matching._run_job(
-            job_path=f"/{self.model_id}/predict",
+            job_path=f"/predict",
+            status_path=f"/jobs/",
+            id=self.id,
             match_from=self.dump_entities(match_from),
             match_to=self.dump_entities(match_to),
             num_matches=num_matches,
             score_threshold=score_threshold,
-            complete_missing=complete_missing,
-        )
-
-    def predict_ml(
-        self,
-        match_from: Optional[List[Dict]] = None,
-        match_to: Optional[List[Dict]] = None,
-        num_matches=1,
-        score_threshold=None,
-        complete_missing=False,
-    ) -> ContextualizationJob:
-        """Duplicate of predict will eventually be removed"""
-        self.wait_for_completion()
-        return self._cognite_client.entity_matching._run_job(
-            job_path=f"/{self.model_id}/predict",
-            match_from=self.dump_entities(match_from),
-            match_to=self.dump_entities(match_to),
-            num_matches=num_matches,
-            score_threshold=score_threshold,
-            complete_missing=complete_missing,
         )
 
     def refit(self, true_matches: List[Tuple[int, int]]) -> "EntityMatchingModel":
-        """Re-fits an entity matching on updated data.
+        """Re-fits an entity matching model, using the combination of the old and new true matches.
 
         Args:
             true_matches: Updated known valid matches given as a list of (id_from,id_to).
         Returns:
-            EntityMatchingModel: new model refitted to ."""
+            EntityMatchingModel: new model refitted to true_matches."""
         self.wait_for_completion()
-        return self._cognite_client.entity_matching._fit_model(
-            model_path=f"/{self.model_id}/refit", true_matches=true_matches
+        response = self._cognite_client.entity_matching._camel_post(
+            f"/refit", json={"trueMatches": true_matches, "id": self.id}
         )
+        return self._load(response.json(), cognite_client=self._cognite_client)
 
     @staticmethod
     def dump_entities(entities: List[Union[Dict, CogniteResource]]) -> Optional[List[Dict]]:
@@ -204,6 +194,27 @@ class EntityMatchingModel(ContextualizationModel):
             ]
 
 
-class ContextualizationModelList(CogniteResourceList):
-    _RESOURCE = ContextualizationModel
-    _ASSERT_CLASSES = False
+class EntityMatchingModelUpdate(CogniteUpdate):
+    """Changes applied to entity matching model
+
+    Args:
+        id (int): A server-generated ID for the object.
+        external_id (str): The external ID provided by the client. Must be unique for the resource type.
+    """
+
+    class _PrimitiveUpdate(CognitePrimitiveUpdate):
+        def set(self, value: Any) -> "EntityMatchingModelUpdate":
+            return self._set(value)
+
+    @property
+    def name(self):
+        return EntityMatchingModelUpdate._PrimitiveUpdate(self, "name")
+
+    @property
+    def description(self):
+        return EntityMatchingModelUpdate._PrimitiveUpdate(self, "description")
+
+
+class EntityMatchingModelList(CogniteResourceList):
+    _RESOURCE = EntityMatchingModel
+    _UPDATE = EntityMatchingModelUpdate
